"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NIconWrapper = void 0;
const vue_1 = require("vue");
const _mixins_1 = require("../../_mixins");
const _utils_1 = require("../../_utils");
const styles_1 = require("../styles");
const index_cssr_1 = __importDefault(require("./styles/index.cssr"));
const iconWrapperProps = Object.assign(Object.assign({}, _mixins_1.useTheme.props), { size: {
        type: Number,
        default: 24
    }, borderRadius: {
        type: Number,
        default: 6
    }, color: String, iconColor: String });
exports.NIconWrapper = (0, vue_1.defineComponent)({
    name: 'IconWrapper',
    props: iconWrapperProps,
    setup(props, { slots }) {
        const themeRef = (0, _mixins_1.useTheme)('IconWrapper', '-icon-wrapper', index_cssr_1.default, styles_1.iconWrapperLight, props);
        const { mergedClsPrefixRef, NConfigProvider } = (0, _mixins_1.useConfig)(props);
        const { disableInlineTheme } = NConfigProvider || {};
        const cssVarsRef = (0, vue_1.computed)(() => {
            const { common: { cubicBezierEaseInOut }, self: { color, iconColor } } = themeRef.value;
            return {
                '--n-bezier': cubicBezierEaseInOut,
                '--n-color': color,
                '--n-icon-color': iconColor
            };
        });
        const themeClassHandle = disableInlineTheme
            ? (0, _mixins_1.useThemeClass)('icon-wrapper', undefined, cssVarsRef, props)
            : _mixins_1.emptyThemeClassHandle;
        return () => {
            var _a, _b;
            const size = (0, _utils_1.formatLength)(props.size);
            (_a = themeClassHandle.onRender) === null || _a === void 0 ? void 0 : _a.call(themeClassHandle);
            return ((0, vue_1.h)("div", { class: [
                    `${mergedClsPrefixRef.value}-icon-wrapper`,
                    (_b = themeClassHandle === null || themeClassHandle === void 0 ? void 0 : themeClassHandle.themeClass) === null || _b === void 0 ? void 0 : _b.value
                ], style: [
                    cssVarsRef === null || cssVarsRef === void 0 ? void 0 : cssVarsRef.value,
                    {
                        height: size,
                        width: size,
                        borderRadius: (0, _utils_1.formatLength)(props.borderRadius),
                        backgroundColor: props.color,
                        color: props.iconColor
                    }
                ] }, slots));
        };
    }
});
